@@ -4,7 +4,7 @@ from oauthlib import oauth2
 from oauthlib.common import urlencode, urlencoded, quote
 
 from .exceptions import OAuthToolkitError, FatalClientError
-from .oauth2_validators import OAuth2Validator
+from .settings import oauth2_settings
 from .compat import urlparse, urlunparse
 
 
@@ -16,7 +16,7 @@ class OAuthLibCore(object):
         """
         :params server: An instance of oauthlib.oauth2.Server class
         """
-        self.server = server or oauth2.Server(OAuth2Validator())
+        self.server = server or oauth2.Server(oauth2_settings.OAUTH2_VALIDATOR_CLASS())
 
     def _get_escaped_full_path(self, request):
         """
@@ -80,7 +80,7 @@ class OAuthLibCore(object):
             if not allow:
                 raise oauth2.AccessDeniedError()
 
-            # add current user to credentials. this will be used by OAuth2Validator
+            # add current user to credentials. this will be used by OAUTH2_VALIDATOR_CLASS
             credentials['user'] = request.user
 
             headers, body, status = self.server.create_authorization_response(
@@ -126,8 +126,7 @@ def get_oauthlib_core():
     Utility function that take a request and returns an instance of
     `oauth2_provider.backends.OAuthLibCore`
     """
-    from oauth2_provider.oauth2_validators import OAuth2Validator
     from oauthlib.oauth2 import Server
 
-    server = Server(OAuth2Validator())
+    server = Server(oauth2_settings.OAUTH2_VALIDATOR_CLASS())
     return OAuthLibCore(server)
